@@ -5,12 +5,16 @@ import logging
 import numpy as np
 from scipy import sparse as sp
 from rdkit import Chem
+from rdkit import RDLogger
 
 from ..readers import Mol2, Mol2Block
 from ..readers import Smiles
 from ..readers import PDB, PartialPDB, PDBBB
 from ..readers import CanonicalAtomOrderConverter
 from ..readers.readmol import MolReader, MolBlock
+from ..readers.basereader import MolFragmentsLabel
+
+RDLogger.DisableLog("rdApp.*")
 
 
 class TestReadingMol2File(unittest.TestCase):
@@ -105,7 +109,7 @@ class TestReadingMol2File(unittest.TestCase):
         bond = self.block.bonds[16]
         self.assertEqual(bond["connect"][0], 6)
         self.assertEqual(bond["connect"][1], 7)
-        self.assertEqual(bond["type"], "am")
+        self.assertEqual(bond["type"], "1")
 
 
 class TestBlockMissingInformation(unittest.TestCase):
@@ -177,11 +181,11 @@ class TestMol2(TestReadingMol2File):
 
     def test_atom2int_and_bond2int(self):
         self.assertEqual(Mol2Block.atom_to_num("C"), 0)
-        self.assertEqual(Mol2Block.atom_to_num("Any"), 22)
-        self.assertEqual(Mol2Block.atom_to_num("@#$%"), 22)
+        self.assertEqual(Mol2Block.atom_to_num("Any"), 24)
+        self.assertEqual(Mol2Block.atom_to_num("@#$%"), 24)
         self.assertEqual(Mol2Block.bond_to_num("1"), 0)
-        self.assertEqual(Mol2Block.bond_to_num("nc"), 6)
-        self.assertEqual(Mol2Block.bond_to_num("@#$%"), 6)
+        self.assertEqual(Mol2Block.bond_to_num("ar"), 3)
+        self.assertEqual(Mol2Block.bond_to_num("@#$%"), 4)
 
     def test_get_atom_features(self):
         atom_features = self.mol.get_atom_features(numeric=False)
@@ -201,11 +205,15 @@ class TestMol2(TestReadingMol2File):
         bond_features = self.mol.get_bond_features(numeric=False)
         self.assertEqual(len(bond_features), self.mol.n_mols)
         self.assertEqual(len(bond_features[0]), self.block.num_bonds * 2)
-        self.assertTrue(isinstance(bond_features[0]["1-2"], str))
+        self.assertIsInstance(bond_features[0]["1-2"], list)
+        self.assertIsInstance(bond_features[0]["1-2"][0], str)
+        self.assertEqual(bond_features[0]["1-2"][1], Chem.rdchem.BondDir.NONE)
         numeric_features = self.mol.get_bond_features(numeric=True)
         self.assertEqual(len(numeric_features), self.mol.n_mols)
         self.assertEqual(len(numeric_features[0]), self.block.num_bonds * 2)
-        self.assertTrue(isinstance(numeric_features[0]["1-2"], int))
+        self.assertIsInstance(numeric_features[0]["1-2"], list)
+        self.assertIsInstance(numeric_features[0]["1-2"][0], int)
+        self.assertIsInstance(numeric_features[0]["1-2"][1], int)
 
     def test_to_graphs(self):
         graphs = self.mol.to_graphs(sparse=False)
@@ -217,10 +225,12 @@ class TestMol2(TestReadingMol2File):
         self.assertEqual(graphs[0]["adjacency"].shape, (28, 28))
         self.assertEqual(len(graphs[0]["atom_features"]), self.block.num_atoms)
         self.assertEqual(len(graphs[0]["atom_features"][0]), 7)
-        self.assertTrue(isinstance(graphs[0]["atom_features"][0][0], float))
-        self.assertTrue(isinstance(graphs[0]["atom_features"][0][-1], int))
+        self.assertIsInstance(graphs[0]["atom_features"][0][0], float)
+        self.assertIsInstance(graphs[0]["atom_features"][0][-1], int)
         self.assertEqual(len(graphs[0]["bond_features"]), self.block.num_bonds * 2)
-        self.assertTrue(isinstance(graphs[0]["bond_features"]["1-2"], int))
+        self.assertIsInstance(graphs[0]["bond_features"]["1-2"], list)
+        self.assertIsInstance(graphs[0]["bond_features"]["1-2"][0], int)
+        self.assertIsInstance(graphs[0]["bond_features"]["1-2"][1], int)
         sparse_graphs = self.mol.to_graphs(sparse=True)
         self.assertEqual(len(sparse_graphs), self.mol.n_mols)
         self.assertTrue(sp.issparse(sparse_graphs[0]["adjacency"]))
@@ -243,8 +253,7 @@ class TestMol2(TestReadingMol2File):
 
 class TestReadingSmiles(unittest.TestCase):
     def setUp(self):
-        # Aspirin
-        self.smiles = "CC(=O)OC1=CC=CC=C1C(=O)O"
+        self.smiles = "CC(=O)Oc1ccccc1C(=O)O"  # Aspirin
         self.sm = Smiles(self.smiles)
 
     def test_building_mol(self):
@@ -270,15 +279,15 @@ class TestReadingSmiles(unittest.TestCase):
     def test_atom_featurs(self):
         feats = self.sm.get_atom_features()
         self.assertEqual(len(feats), 13)
-        self.assertEqual(feats[0], ("C", 1, 0, 4, 0, 0))
-        self.assertEqual(feats[4], ("C", 3, 0, 3, 1, 0))
+        self.assertEqual(feats[0], ("C", 1, 5, 4, 0, 0))
+        self.assertEqual(feats[4], ("C", 3, 5, 3, 1, 0))
         feats = self.sm.get_atom_features(numeric=True)
         self.assertEqual(len(feats), 13)
-        self.assertEqual(feats[0], (0, 1, 0, 4, 0, 0))
+        self.assertEqual(feats[0], (0, 1, 5, 4, 0, 0))
         feats = self.sm.get_atom_features(numeric=True, padding=20)
         self.assertEqual(len(feats), 20)
-        self.assertEqual(feats[0], (0, 1, 0, 4, 0, 0))
-        self.assertEqual(feats[-1], (22, 0, 0, 0, 0, 0))
+        self.assertEqual(feats[0], (0, 1, 5, 4, 0, 0))
+        self.assertEqual(feats[-1], (24, 0, 0, 0, 0, 0))
         with self.assertRaises(ValueError):
             self.sm.get_atom_features(padding=12)
 
@@ -308,10 +317,10 @@ class TestReadingSmiles(unittest.TestCase):
     def test_bond_features(self):
         feats = self.sm.get_bond_features()
         self.assertEqual(len(feats), 26)
-        self.assertEqual(feats["0-1"], "1")
+        self.assertEqual(feats["0-1"][0], "1")
         feats = self.sm.get_bond_features(numeric=True)
         self.assertEqual(len(feats), 26)
-        self.assertEqual(feats["0-1"], 0)
+        self.assertEqual(feats["0-1"][0], 0)
         # feats = self.sm.get_bond_features(numeric=True, padding=15)
         # self.assertEqual(len(feats), 15)
         # self.assertEqual(feats[0], 0)
@@ -322,12 +331,12 @@ class TestReadingSmiles(unittest.TestCase):
     def test_sorted_bond_features(self):
         feats = self.sm.get_bond_features(sort_atoms=True)
         self.assertEqual(len(feats), 26)
-        self.assertEqual(feats["0-5"], "1")
+        self.assertEqual(feats["0-5"][0], "1")
         with self.assertRaises(KeyError):
             feats["0-1"]
         unsorted_feats = self.sm.get_bond_features(sort_atoms=False)
         self.assertEqual(len(unsorted_feats), 26)
-        self.assertEqual(unsorted_feats["0-1"], "1")
+        self.assertEqual(unsorted_feats["0-1"][0], "1")
 
     def test_graph(self):
         graph = self.sm.to_graph()
@@ -345,12 +354,66 @@ class TestReadingSmiles(unittest.TestCase):
     def test_fingerprints(self):
         fp = self.sm.fingerprint
         self.assertEqual(len(fp), 2048)
-        other = Smiles("C1ccccC1")
+        other = Smiles("c1ccccc1")
         self.assertFalse(self.sm.similar_to(other))
         self.assertTrue(self.sm.similar_to(self.sm))
         fp = Smiles("C1").fingerprint
         self.assertIsNone(fp)
 
+    def test_fragment_labels(self):
+        atom_features = self.sm.get_atom_features(numeric=True, fragment_label=True)
+        self.assertEqual(len(atom_features[0]), 624)
+        graph = self.sm.to_graph(fragment_label=True)
+        self.assertEqual(len(graph["atom_features"][0]), 624)
+        # assert the order of the atom fragment labels are correct
+        atom_features = self.sm.get_atom_features(
+            numeric=True, fragment_label=True, sort_atoms=True
+        )
+        mfl = MolFragmentsLabel()
+        frag_labels = mfl.create_labels_for(self.sm.rdkit_mol, sparse=False)
+        for i, atom in enumerate(self.sm.sorted_atoms):
+            idx = atom.GetIdx()
+            self.assertEqual(atom_features[i][6:], tuple(frag_labels[:, idx].tolist()))
+        # assert padding still work
+        atom_features = self.sm.get_atom_features(
+            numeric=True, fragment_label=True, padding=70
+        )
+        self.assertEqual(len(atom_features), 70)
+        self.assertEqual(atom_features[-1], tuple([24] + [0] * 623))
+
+    def test_networkx_graph(self):
+        graph = self.sm.to_graph(networkx=True)
+        self.assertEqual(graph.graph["n_atomtypes"], 25)
+        self.assertEqual(graph.nodes[0]["atomtype"], 0)
+        self.assertEqual(graph.nodes[0]["formalcharge"], 5)
+        self.assertEqual(graph.nodes[0]["degree"], 1)
+        self.assertEqual(graph.nodes[0]["hybridization"], 4)
+        self.assertEqual(graph.nodes[0]["aromatic"], 0)
+        self.assertEqual(graph.nodes[0]["chirality"], 0)
+        self.assertEqual(graph.edges[0, 1]["bondtype"], 0)
+        self.assertEqual(graph.edges[0, 1]["bonddir"], 0)
+
+    def test_pyg_graph(self):
+        try:
+            import torch
+            import torch_geometric as pyg
+
+            torch_avail = True
+        except ImportError:
+            torch_avail = False
+
+        if torch_avail:
+            with self.assertRaises(AssertionError):
+                self.sm.to_graph(networkx=True, pyg=True)
+            graph = self.sm.to_graph(pyg=True)
+            self.assertIsInstance(graph, pyg.data.Data)
+            self.assertTrue(hasattr(graph, "x"))
+            self.assertTrue(hasattr(graph, "edge_idx"))
+            self.assertTrue(hasattr(graph, "edge_attr"))
+            self.assertIsInstance(graph["edge_idx"], torch.Tensor)
+            self.assertIsInstance(graph["edge_attr"], torch.Tensor)
+            self.assertEqual(graph["edge_idx"].size(1), graph["edge_attr"].size(0))
+
 
 class TestReadPDB(unittest.TestCase):
     def setUp(self):
@@ -385,6 +448,13 @@ class TestReadPDB(unittest.TestCase):
             graph["atom_features"][-1][:3], tuple(conformer.GetAtomPosition(10))
         )
 
+    def test_coordinates_included_in_atom_features(self):
+        pdb = PDB(self.fpath)
+        feats = pdb.get_atom_features(include_coordinates=True)
+        self.assertEqual(len(feats[0]), 9)
+        graph = pdb.to_graph(include_coordinates=True)
+        self.assertEqual(len(graph["atom_features"][0]), 9)
+
     def test_coordinates(self):
         pdb = PDB(self.fpath, sanitize=False)
         counter = 0
@@ -417,6 +487,63 @@ class TestReadPDB(unittest.TestCase):
         self.assertEqual(len(atom_features), adj.shape[0])
         self.assertEqual(len(atom_features[0]), 5)
 
+    def test_fragment_labels(self):
+        pdb = PDB(self.fpath, sanitize=False)
+        atom_features = pdb.get_atom_features(numeric=True, fragment_label=True)
+        self.assertEqual(len(atom_features[0]), 624)
+        graph = pdb.to_graph(fragment_label=True)
+        self.assertEqual(len(graph["atom_features"][0]), 624)
+        # assert the order of the atom fragment labels are correct
+        atom_features = pdb.get_atom_features(
+            numeric=True, fragment_label=True, sort_atoms=True
+        )
+        mfl = MolFragmentsLabel()
+        frag_labels = mfl.create_labels_for(pdb.rdkit_mol, sparse=False)
+        for i, atom in enumerate(pdb.sorted_atoms):
+            idx = atom.GetIdx()
+            self.assertEqual(atom_features[i][6:], tuple(frag_labels[:, idx].tolist()))
+        # assert padding still work
+        atom_features = pdb.get_atom_features(
+            numeric=True, fragment_label=True, padding=2618
+        )
+        self.assertEqual(len(atom_features), 2618)
+        self.assertEqual(atom_features[-1], tuple([24] + [0] * 623))
+
+    def test_networkx_graph(self):
+        pdb = PDB(self.fpath, sanitize=False)
+        graph = pdb.to_graph(networkx=True)
+        self.assertEqual(graph.graph["n_atomtypes"], 25)
+        self.assertEqual(graph.nodes[0]["atomtype"], 1)
+        self.assertEqual(graph.nodes[0]["formalcharge"], 0)
+        self.assertEqual(graph.nodes[0]["degree"], 1)
+        self.assertEqual(graph.nodes[0]["hybridization"], 0)
+        self.assertEqual(graph.nodes[0]["aromatic"], 0)
+        self.assertEqual(graph.nodes[0]["chirality"], 0)
+        self.assertEqual(graph.edges[0, 1]["bondtype"], 0)
+        self.assertEqual(graph.edges[0, 1]["bonddir"], 0)
+
+    def test_pyg_graph(self):
+        try:
+            import torch
+            import torch_geometric as pyg
+
+            torch_avail = True
+        except ImportError:
+            torch_avail = False
+
+        if torch_avail:
+            pdb = PDB(self.fpath, sanitize=False)
+            with self.assertRaises(AssertionError):
+                pdb.to_graph(networkx=True, pyg=True)
+            graph = pdb.to_graph(include_coordinates=True, pyg=True)
+            self.assertIsInstance(graph, pyg.data.Data)
+            self.assertTrue(hasattr(graph, "x"))
+            self.assertTrue(hasattr(graph, "edge_idx"))
+            self.assertTrue(hasattr(graph, "edge_attr"))
+            self.assertIsInstance(graph["edge_idx"], torch.Tensor)
+            self.assertIsInstance(graph["edge_attr"], torch.Tensor)
+            self.assertEqual(graph["edge_idx"].size(1), graph["edge_attr"].size(0))
+
 
 class TestReadMol(unittest.TestCase):
     def setUp(self):
@@ -489,18 +616,10 @@ class TestAtomOrderConverter(unittest.TestCase):
         conv1 = CanonicalAtomOrderConverter(self.mol1)
         conv2 = CanonicalAtomOrderConverter(self.mol2)
         conv3 = CanonicalAtomOrderConverter(self.mol3)
-        conv4 = CanonicalAtomOrderConverter(self.mol4)
-        conv5 = CanonicalAtomOrderConverter(self.mol5)
-        conv6 = CanonicalAtomOrderConverter(self.mol6)
 
         new_mol1 = conv1.convert()
         new_mol2 = conv2.convert()
         new_mol3 = conv3.convert()
-        new_mol4 = conv4.convert()
-        new_mol5 = conv5.convert()
-        new_mol6 = conv6.convert()
 
         self.assert_mols_equal(new_mol1, new_mol2)
         self.assert_mols_equal(new_mol1, new_mol3)
-        self.assert_mols_equal(new_mol4, new_mol5)
-        self.assert_mols_equal(new_mol4, new_mol6)
